"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_native_macos_1 = require("react-native-macos");
var react_1 = require("react");
var nativeCache = react_native_macos_1.NativeModules.RNSVGKImageCache;
// Track the user count of each cache key.
var userCounts = {};
function useSvg(options) {
    var cacheKey = react_1.useMemo(function () { return (options.data || options.source ? preloadSvg(options) : void 0); }, Object.values(options));
    react_1.useEffect(function () {
        if (cacheKey) {
            return function () { return unloadSvg(cacheKey); };
        }
    }, [cacheKey]);
    return cacheKey;
}
exports.useSvg = useSvg;
/** Preload an `<svg>` into memory. Returns the cache key. */
function preloadSvg(options) {
    if (!options.key && !options.source) {
        throw Error('Cannot preload an <svg> string without a cache key');
    }
    var source = options.source
        ? react_native_macos_1.Image.resolveAssetSource(options.source)
        : void 0;
    var cacheKey = options.key || source.uri;
    if (!userCounts[cacheKey]) {
        userCounts[cacheKey] = 1;
        nativeCache.preloadSvg(__assign(__assign({}, (source || { data: options.data })), { key: options.key }));
    }
    else {
        userCounts[cacheKey]++;
    }
    return cacheKey;
}
exports.preloadSvg = preloadSvg;
/**
 * Reclaim memory taken by cached `<svg>` data.
 *
 * Does not affect views which are using the cached data.
 */
function unloadSvg(cacheKey) {
    if (userCounts[cacheKey]) {
        if (userCounts[cacheKey] == 1) {
            delete userCounts[cacheKey];
            nativeCache.unloadSvg(cacheKey);
        }
        else {
            userCounts[cacheKey]--;
        }
    }
}
exports.unloadSvg = unloadSvg;
//# sourceMappingURL=SVGKCache.js.map